instrumenttools.WoodwindFingering
=================================

.. abjad-lineage:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering

.. autoclass:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.center_column
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.instrument_name
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.left_hand
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.print_guide
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.right_hand
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__call__
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__eq__
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__format__
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__ne__
      ~abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.center_column
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.left_hand
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.right_hand
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.print_guide
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__format__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.WoodwindFingering.WoodwindFingering.__repr__
   :noindex:
